@@ -22,12 +22,20 @@ ASKCONFIRMATION=1
 OVERWRITEDIR="ask"
 USEVIRTUALENV="yes"
 
-PYTHON="$(which python)"
-BASE_PIP_URL="https://pypi.python.org/simple"
-VIRTUALENV_191_URL="https://raw.github.com/pypa/virtualenv/1.9.1/virtualenv.py"
-VIRTUALENV_CMD="virtualenv"
+# ansi colors for formatting heredoc
+ESC=$(printf "\e")
+GREEN="$ESC[0;32m"
+NO_COLOR="$ESC[0;0m"
+RED="$ESC[0;31m"
 
-RALLY_GIT_URL=https://github.com/openstack/rally
+PYTHON2="$(which python || true)"
+PYTHON3="$(which python3 || true)"
+PYTHON=${PYTHON2:-$PYTHON3}
+BASE_PIP_URL=${BASE_PIP_URL:-"https://pypi.python.org/simple"}
+VIRTUALENV_191_URL="https://raw.github.com/pypa/virtualenv/1.9.1/virtualenv.py"
+
+RALLY_GIT_URL="https://github.com/openstack/rally"
+RALLY_GIT_BRANCH="master"
 RALLY_CONFIGURATION_DIR=/etc/rally
 RALLY_DATABASE_DIR=/var/lib/rally/database
 DBTYPE=sqlite
@@ -58,14 +66,6 @@ EX_TEMPFAIL=75
 # misused as: unexpected error in some script we call
 EX_PROTOCOL=76
 
-err () {
-  echo "$PROG: $@" >&2
-}
-
-say () {
-    echo "$PROG: $@";
-}
-
 # abort RC [MSG]
 #
 # Print error message MSG and abort shell execution with exit code RC.
@@ -74,7 +74,7 @@ say () {
 abort () {
   local rc="$1"
   shift
-  (echo -n "$PROG: ERROR: ";
+  (echo -en "$RED$PROG: ERROR: $NO_COLOR";
       if [ $# -gt 0 ]; then echo "$@"; else cat; fi) 1>&2
   exit "$rc"
 }
@@ -90,10 +90,10 @@ die () {
   header="$2"
   shift 2
   cat 1>&2 <<__EOF__
-==========================================================
+$RED==========================================================
 $PROG: ERROR: $header
 ==========================================================
-
+$NO_COLOR
 __EOF__
   if [ $# -gt 0 ]; then
       # print remaining arguments one per line
@@ -110,14 +110,14 @@ If the above does not help you resolve the issue, please contact the
 Rally team by sending an email to the OpenStack mailing list
 openstack-dev@lists.openstack.org. Include the full output of this
 script to help us identifying the problem.
-
-Aborting installation!
+$RED
+Aborting installation!$NO_COLOR
 __EOF__
   exit "$rc"
 }
 
 script_interrupted () {
-    say "Interrupted by the user. Cleaning up..."
+    echo "Interrupted by the user. Cleaning up..."
     [ -n "${VIRTUAL_ENV}" -a "${VIRTUAL_ENV}" == "$VENVDIR" ] && deactivate
 
     case $CURRENT_ACTION in
@@ -144,9 +144,7 @@ script_interrupted () {
             ;;
     esac
 
-    die $EX_TEMPFAIL "Script interrupted by the user" <<__EOF__
-
-__EOF__
+    abort $EX_TEMPFAIL "Script interrupted by the user"
 }
 
 trap script_interrupted SIGINT
@@ -158,26 +156,37 @@ Usage: $PROG [options]
 This script will install Rally in your system.
 
 Options:
-  -h, --help             Print this help text
-  -v, --verbose          Verbose mode
-  -s, --system           Install system-wide.
-  -d, --target DIRECTORY Install Rally virtual environment into DIRECTORY.
+$GREEN  -h, --help            $NO_COLOR Print this help text
+$GREEN  -v, --verbose         $NO_COLOR Verbose mode
+$GREEN  -s, --system          $NO_COLOR Install system-wide.
+$GREEN  -d, --target DIRECTORY$NO_COLOR Install Rally virtual environment into DIRECTORY.
                          (Default: $HOME/rally if not root).
-  -f, --overwrite        Remove target directory if it already exists.
-  -y, --yes              Do not ask for confirmation: assume a 'yes' reply
+$GREEN  --url                 $NO_COLOR Git repository public URL to download Rally from.
+                         This is useful when you have only installation script and want to install Rally
+                         from custom repository.
+                         (Default: https://github.com/openstack/rally).
+                         (Ignored when you are already in git repository).
+$GREEN  --branch              $NO_COLOR Git branch name name or git tag (Rally release) to install.
+                         (Default: latest - master).
+                         (Ignored when you are already in git repository).
+$GREEN  -f, --overwrite       $NO_COLOR Remove target directory if it already exist.
+$GREEN  -y, --yes             $NO_COLOR Do not ask for confirmation: assume a 'yes' reply
                          to every question.
-  -D, --dbtype TYPE      Select the database type. TYPE can be one of
+$GREEN  -D, --dbtype TYPE     $NO_COLOR Select the database type. TYPE can be one of
                          'sqlite', 'mysql', 'postgres'.
                          Default: sqlite
-  --db-user USER         Database user to use. Only used when --dbtype
+$GREEN  --db-user USER        $NO_COLOR Database user to use. Only used when --dbtype
                          is either 'mysql' or 'postgres'.
-  --db-password PASSWORD Password of the database user. Only used when
+$GREEN  --db-password PASSWORD$NO_COLOR Password of the database user. Only used when
                          --dbtype is either 'mysql' or 'postgres'.
-  --db-host HOST         Database host. Only used when --dbtype is
+$GREEN  --db-host HOST        $NO_COLOR Database host. Only used when --dbtype is
                          either 'mysql' or 'postgres'
-  --db-name NAME         Name of the database. Only used when --dbtype is
+$GREEN  --db-name NAME        $NO_COLOR Name of the database. Only used when --dbtype is
                          either 'mysql' or 'postgres'
-  -p, --python EXE       The python interpreter to use. Default: $(which python).
+$GREEN  -p, --python EXE      $NO_COLOR The python interpreter to use. Default: $PYTHON
+$GREEN  --develop             $NO_COLOR Install Rally with editable source code try.
+                         (Default: false)
+$GREEN  --no-color            $NO_COLOR Disable output coloring.
 
 __EOF__
 }
@@ -200,7 +209,7 @@ ask_yn () {
         case "$REPLY" in
             [Yy]*)    REPLY='yes'; return 0 ;;
             [Nn]*|'') REPLY='no';  return 1 ;;
-            *)        say "Please type 'y' (yes) or 'n' (no)." ;;
+            *)        echo "Please type 'y' (yes) or 'n' (no)." ;;
         esac
     done
 }
@@ -217,11 +226,12 @@ require_command () {
 
 require_python () {
     require_command "$PYTHON"
-    if $PYTHON -c 'import sys; sys.exit(sys.version_info[:2] >= (2, 6))'; then
+    if "$PYTHON" -c 'import sys; sys.exit(sys.version_info[:2] >= (2, 6))'
+    then
         die $EX_UNAVAILABLE "Wrong version of python is installed" <<__EOF__
 
 Rally requires Python version 2.6+. Unfortunately, we do not support
-your version of python: $($PYTHON -V 2>&1|sed 's/python//gi').
+your version of python: $("$PYTHON" -V 2>&1 | sed 's/python//gi').
 
 If a version of Python suitable for using Rally is present in some
 non-standard location, you can specify it from the command line by
@@ -254,29 +264,9 @@ which_missing_packages () {
 }
 
 # Download command
-# TODO: move this logic into install_required_sw
-if ! have_command wget && ! have_command curl; then
-    if ask_yn "You need ether wget or curl to be installed. Install wget?"; then
-        apt-get install -yes wget || yum install -y wget
-    fi
-fi
-
-if have_command wget
-then
-    download () { wget -nv $VERBOSE --no-check-certificate -O "$@"; }
-elif have_command curl
-then
-    download () { curl $VERBOSE --insecure -L -s -o "$@"; }
-else
-    die $EX_UNAVAILABLE "Neither 'curl' nor 'wget' command found." <<__EOF__
-The script needs either one of the 'curl' or 'wget' commands to run.
-Please, install at least one of them using the software manager of
-your distribution, or downloading it from internet:
-
-- wget: http://www.gnu.org/software/wget/
-- curl: http://curl.haxx.se/
-__EOF__
-fi
+download() {
+    wget -nv $VERBOSE --no-check-certificate -O "$@";
+}
 
 download_from_pypi () {
     local pkg=$1
@@ -296,17 +286,16 @@ install_required_sw () {
     local missing pkg_manager
     if have_command apt-get; then
         # Debian/Ubuntu
-        missing=$(which_missing_packages build-essential libssl-dev libffi-dev python-dev libxml2-dev libxslt1-dev libpq-dev git)
+        missing=$(which_missing_packages build-essential libssl-dev libffi-dev python-dev libxml2-dev libxslt1-dev libpq-dev git wget)
 
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="apt-get install --yes"
         else
             pkg_manager="apt-get install"
         fi
-
     elif have_command yum; then
         # RHEL/CentOS
-        missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel git)
+        missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel git wget)
 
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="yum install -y"
@@ -315,12 +304,17 @@ install_required_sw () {
         fi
     elif have_command zypper; then
         # SuSE
-        warn "Cannot check if requisite software is installed: SuSE and compatible Linux distributions are not yet supported. I'm proceeding anyway, but you may run into errors later."
+        missing=$(which_missing_packages gcc libffi48-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql93-devel git wget)
+
+        if [ "$ASKCONFIRMATION" -eq 0 ]; then
+            pkg_manager="zypper -n --no-gpg-checks --non-interactive install --auto-agree-with-licenses"
+        else
+            pkg_manager="zypper install"
+        fi
     else
         # MacOSX maybe?
-        warn "Cannot determine what package manager this Linux distribution has, so I cannot check if requisite software is installed. I'm proceeding anyway, but you may run into errors later."
+        echo "Cannot determine what package manager this Linux distribution has, so I cannot check if requisite software is installed. I'm proceeding anyway, but you may run into errors later."
     fi
-
     if ! have_command pip; then
         missing="$missing python-pip"
     fi
@@ -328,8 +322,8 @@ install_required_sw () {
     if [ -n "$missing" ]; then
         cat <<__EOF__
 The following software packages need to be installed
-in order for Rally to work: $missing
-
+in order for Rally to work:$GREEN $missing
+$NO_COLOR
 __EOF__
 
         # If we are root
@@ -337,30 +331,31 @@ __EOF__
             cat <<__EOF__
 In order to install the required software you would need to run as
 'root' the following command:
-
+$GREEN
     $pkg_manager $missing
-
+$NO_COLOR
 __EOF__
             # ask if we have to install it
             if ask_yn "Do you want me to install these packages for you?"; then
                 # install
                 if [[ "$missing" == *python-pip* ]]; then
-                    missing=$(echo "$missing" | sed 's/python-pip//')
+                    missing=${missing//python-pip/}
                     if ! $pkg_manager python-pip; then
                         if ask_yn "Error installing python-pip. Install from external source?"; then
                             local pdir=$(mktemp -d)
                             local getpip="$pdir/get-pip.py"
                             download "$getpip" https://raw.github.com/pypa/pip/master/contrib/get-pip.py
-                            if ! $PYTHON "$getpip"; then
-                                die $EX_PROTOCOL "Error while installing python-pip from external source."
+                            if ! "$PYTHON" "$getpip"; then
+                                abort $EX_PROTOCOL "Error while installing python-pip from external source."
                             fi
                         else
-                            die $EX_TEMPFAIL "Please install python-pip manually."
+                            abort $EX_TEMPFAIL \
+                                "Please install python-pip manually."
                         fi
                     fi
                 fi
                 if ! $pkg_manager $missing; then
-                    die $EX_UNAVAILABLE "Error while installing $missing"
+                    abort $EX_UNAVAILABLE "Error while installing $missing"
                 fi
                 # installation successful
             else # don't want to install the packages
@@ -380,15 +375,15 @@ likely to fail!
 __EOF__
             if ask_yn "Proceed with installation anyway?"
             then
-                warn "Proceeding with installation at your request... keep fingers crossed!"
+                echo "Proceeding with installation at your request... keep fingers crossed!"
             else
                 die $EX_UNAVAILABLE "missing software prerequisites" <<__EOF__
 Please ask your system administrator to install the missing packages,
 or, if you have root access, you can do that by running the following
 command from the 'root' account:
-
+$GREEN
     $pkg_manager $missing
-
+$NO_COLOR
 __EOF__
             fi
         fi
@@ -411,29 +406,19 @@ install_virtualenv () {
     DESTDIR=$1
 
     if [ -n "$VIRTUAL_ENV" ]; then
-        cat <<__EOF__
-
-ERROR
-=====
-
-A virtual environment seems to be already *active*. This will cause
+        die $EX_SOFTWARE "Virtualenv already active" <<__EOF__
+A virtual environment seems to be already active. This will cause
 this script to FAIL.
 
 Run 'deactivate', then run this script again.
-
 __EOF__
-        exit $EX_SOFTWARE
     fi
 
     # Use the latest virtualenv that can use `.tar.gz` files
-    VIRTUALENV_URL=$VIRTUALENV_191_URL
     VIRTUALENV_DST="$DESTDIR/virtualenv-191.py"
-    mkdir -p $DESTDIR
-    download $VIRTUALENV_DST $VIRTUALENV_URL
-    VIRTUALENV_CMD="$PYTHON $VIRTUALENV_DST"
-
-    # python virtualenv.py --[no,system]-site-packages $DESTDIR
-    $VIRTUALENV_CMD $VERBOSE -p $PYTHON "$DESTDIR"
+    mkdir -p "$DESTDIR"
+    download "$VIRTUALENV_DST" "$VIRTUALENV_191_URL"
+    "$PYTHON" "$VIRTUALENV_DST" $VERBOSE -p "$PYTHON" "$DESTDIR"
 
     . "$DESTDIR"/bin/activate
 
@@ -445,7 +430,11 @@ __EOF__
     #
     if pip wheel --help 1>/dev/null 2>/dev/null; then
         (cd "$DESTDIR" && download_from_pypi setuptools)
-        if ! (cd "$DESTDIR" && tar -xzf setuptools-*.tar.gz && cd setuptools-* && python setup.py install);
+        # setup.py must be called with `python', which will be the
+        # python executable inside the virtualenv, not `$PYTHON',
+        # which is the system python.
+        if ! (cd "$DESTDIR" && tar -xzf setuptools-*.tar.gz && \
+              cd setuptools-* && python setup.py install);
         then
             die $EX_SOFTWARE \
                 "Failed to install the latest version of Python 'setuptools'" <<__EOF__
@@ -472,9 +461,10 @@ setup_rally_configuration () {
 
 
 ### Main program ###
-short_opts='d:vfsyhD:p:'
-long_opts='target:,verbose,overwrite,system,yes,dbtype:,python:,db-user:,db-password:,db-host:,db-name:,help'
+short_opts='d:vsyfhD:p:'
+long_opts='target:,verbose,overwrite,system,yes,dbtype:,python:,db-user:,db-password:,db-host:,db-name:,help,url:,branch:,develop,no-color'
 
+set +e
 if [ "x$(getopt -T)" = 'x' ]; then
     # GNU getopt
     args=$(getopt --name "$PROG" --shell sh -l "$long_opts" -o "$short_opts" -- "$@")
@@ -487,10 +477,11 @@ else
     # old-style getopt, use compatibility syntax
     args=$(getopt "$short_opts" "$@")
     if [ $? -ne 0 ]; then
-        abort 1 "Type '$PROG --help' to get usage information."
+        abort 1 "Type '$PROG -h' to get usage information."
     fi
     eval set -- "$args"
 fi
+set -e
 
 # Command line parsing
 while true
@@ -498,7 +489,7 @@ do
     case "$1" in
         -d|--target)
             shift
-            VENVDIR=$1
+            VENVDIR=$(readlink -m "$1")
             ;;
         -h|--help)
             print_usage
@@ -515,17 +506,23 @@ do
             ;;
         -y|--yes)
             ASKCONFIRMATION=0
-            OVERWRITEDIR=yes
+            ;;
+        --url)
+            shift
+            RALLY_GIT_URL=$1
+            ;;
+        --branch)
+            shift
+            RALLY_GIT_BRANCH=$1
             ;;
         -D|--dbtype)
             shift
             DBTYPE=$1
             case $DBTYPE in
-                sqlite|mysql|postgres) break ;;
+                sqlite|mysql|postgres);;
                 *)
-                    err "Invalid database type $DBTYPE."
-                    print_usage
-                    exit $EX_USAGE
+                    print_usage | die $EX_USAGE \
+                        "An invalid option has been detected."
                     ;;
             esac
             ;;
@@ -549,14 +546,20 @@ do
             shift
             PYTHON=$1
             ;;
+        --develop)
+            DEVELOPMENT_MODE=true
+            ;;
+        --no-color)
+            RED=""
+            GREEN=""
+            NO_COLOR=""
+            ;;
         --)
             shift
             break
             ;;
         *)
-            err "An invalid option has been detected."
-            print_usage
-            exit $EX_USAGE
+            print_usage | die $EX_USAGE "An invalid option has been detected."
     esac
     shift
 done
@@ -576,8 +579,8 @@ if running_as_root; then
 else
     if [ "$USEVIRTUALENV" == 'no' ]; then
         die $EX_USAGE "Insufficient privileges" <<__EOF__
-Root permissions required in order to install system-wide.
-As non-root user you may only install in virtualenv.
+$REDRoot permissions required in order to install system-wide.
+As non-root user you may only install in virtualenv.$NO_COLOR
 __EOF__
     fi
     if [ -z "$VENVDIR" ]; then
@@ -588,12 +591,18 @@ fi
 # Fix RALLY_DATABASE_DIR if virtualenv is used
 if [ "$USEVIRTUALENV" = 'yes' ]
 then
-    RALLY_CONFIGURATION_DIR=~/.rally
+    RALLY_CONFIGURATION_DIR=$VENVDIR/etc/rally
     RALLY_DATABASE_DIR="$VENVDIR"/database
 fi
 
-if [ "$DBTYPE" != 'sqlite' ]
-then
+if [ "$DBTYPE" = 'sqlite' ]; then
+    if [ "${DBNAME:0:1}" = '/' ]; then
+        DBFILE="$DBNAME"
+    else
+        DBFILE="${RALLY_DATABASE_DIR}/${DBNAME}"
+    fi
+    DBCONNSTRING="sqlite:///${DBFILE}"
+else
     if [ -z "$DBUSER" -o -z "$DBPASSWORD" -o -z "$DBHOST" -o -z "$DBNAME" ]
     then
         die $EX_USAGE "Missing mandatory options" <<__EOF__
@@ -602,17 +611,15 @@ to specify the database name, host, and username and password of a
 valid user with write access to the database.
 
 Please, re-run the script with valid values for the options:
-
+$GREEN
     --db-host
     --db-name
     --db-user
-    --db-password
+    --db-password$NO_COLOR
 __EOF__
     fi
     DBAUTH="$DBUSER:$DBPASSWORD@$DBHOST"
     DBCONNSTRING="$DBTYPE://$DBAUTH/$DBNAME"
-else
-    DBCONNSTRING="$DBTYPE:///${RALLY_DATABASE_DIR}/${DBNAME}"
 fi
 
 # check and install prerequisites
@@ -632,8 +639,11 @@ if [ "$USEVIRTUALENV" = 'yes' ]; then
 
             if ! ask_yn "Do you want to wipe the installation directory '$VENVDIR'?"
             then
-                say "*Not* overwriting destination directory '$VENVDIR'."
+                echo "*Not* overwriting destination directory '$VENVDIR'."
                 OVERWRITEDIR=no
+            else
+                echo "Removing directory $VENVDIR as requested."
+                rm $VERBOSE -rf "$VENVDIR"
             fi
         elif [ $OVERWRITEDIR = 'no' ]
         then
@@ -649,7 +659,7 @@ if [ "$USEVIRTUALENV" = 'yes' ]; then
       overwrite the $VENVDIR directory, or
 
     * specify a different path by running this script again adding the
-      option "--target" followed by a non-existent directory.
+      option: "--target" followed by a non-existent directory.
 __EOF__
         elif [ $OVERWRITEDIR = 'yes' ]; then
             echo "Removing directory $VENVDIR as requested."
@@ -679,6 +689,28 @@ BASEDIR=$(dirname "$(readlink -e "$0")")
 if [ -d "$BASEDIR"/.git ]
 then
     SOURCEDIR=$BASEDIR
+    pushd $BASEDIR > /dev/null
+    if find . -name '*.py[co]' -exec rm -f {} +
+    then
+        echo "Wiped python compiled files."
+    else
+        echo "Warning! Unable to wipe python compiled files"
+    fi
+
+    if [ "$USEVIRTUALENV" = 'yes' ]
+    then
+        if [ "$VENVDIR/src" != "$BASEDIR" ]
+        then
+            SOURCEDIR="$VENVDIR"/src
+            if [ -d $SOURCEDIR ]
+            then
+                rm -rf $SOURCEDIR
+            fi
+            mkdir $SOURCEDIR
+            cp -r . $SOURCEDIR/
+        fi
+    fi
+    popd > /dev/null
 else
     if [ "$USEVIRTUALENV" = 'yes' ]
     then
@@ -699,25 +731,26 @@ else
             echo
             if ! ask_yn "Do you want to wipe the source directory '$SOURCEDIR'?"
             then
-                say "*Not* overwriting destination directory '$SOURCEDIR'."
+                echo "*Not* overwriting destination directory '$SOURCEDIR'."
+            else
+                rm -rf $SOURCEDIR
+                if [ -d "$SOURCEDIR"/.git ]
+                then
+                    abort $EX_CANTCREAT "Unable to wipe source directory $SOURCEDIR"
+                fi
             fi
         fi
-        if [ -d "$SOURCEDIR"/.git ]
-        then
-            echo "Assuming $SOURCEDIR already contains the Rally git repository."
-        else
-            die $EX_CANTCREAT "Unable to download git repository" <<__EOF__
-Unable to download git repository.
-
-__EOF__
-        fi
     fi
 
     if ! [ -d "$SOURCEDIR"/.git ]
     then
         echo "Downloading Rally from subversion repository $RALLY_GIT_URL ..."
         CURRENT_ACTION="downloading-src"
-        git clone "$RALLY_GIT_URL" "$SOURCEDIR"
+        git clone "$RALLY_GIT_URL" -b "$RALLY_GIT_BRANCH" "$SOURCEDIR"
+        if ! [ -d $SOURCEDIR/.git ]
+            then
+            abort $EX_CANTCREAT "Unable to download git repository"
+        fi
         CURRENT_ACTION="src-downloaded"
     fi
 fi
@@ -726,12 +759,22 @@ install_db_connector
 
 # Install rally
 cd "$SOURCEDIR"
+# Get latest available pip and reset shell cache
+pip install -i $BASE_PIP_URL -U 'pip'
+hash -r
+
 # Install dependencies
-pip install pbr
-pip install 'tox<=1.6.1'
+pip install -i $BASE_PIP_URL pbr 'tox<=1.6.1'
+# Uninstall possible previous version
+pip uninstall -y rally || true
 # Install rally
-# python setup.py install
-pip install .
+if [ $DEVELOPMENT_MODE ]
+then
+    pip install -i $BASE_PIP_URL -e .
+else
+    pip install -i $BASE_PIP_URL .
+fi
+
 cd "$ORIG_WD"
 
 # Post-installation
@@ -743,11 +786,29 @@ then
 . "$VENVDIR/etc/bash_completion.d/rally.bash_completion"
 __EOF__
 
+    setup_rally_configuration "$SOURCEDIR"
+
+    if ! [ $DEVELOPMENT_MODE ]
+    then
+        SAMPLESDIR=$VENVDIR/samples
+        mkdir -p $SAMPLESDIR
+        cp -r $SOURCEDIR/samples/* $SAMPLESDIR/
+        if [ "$BASEDR" != "$SOURCEDIR" ]
+        then
+            rm -rf $SOURCEDIR
+            echo "Source directory is removed."
+        else
+            echo "Unabled to remove source directory, becaus this script was started from it."
+        fi
+    else
+        SAMPLESDIR=$SOURCEDIR/samples
+    fi
+
     cat <<__EOF__
-==============================
+$GREEN==============================
 Installation of Rally is done!
 ==============================
-
+$NO_COLOR
 In order to work with Rally you have to enable the virtual environment
 with the command:
 
@@ -758,27 +819,48 @@ using Rally, but just once per session.
 
 Information about your Rally installation:
 
-  * Method: virtualenv
-  * Virtual Environment at: $VENVDIR
-  * Database at: $RALLY_DATABASE_DIR
-  * Configuration file at: $RALLY_CONFIGURATION_DIR
+  * Method:$GREEN virtualenv$NO_COLOR
+  * Virtual Environment at:$GREEN $VENVDIR$NO_COLOR
+  * Database at:$GREEN $RALLY_DATABASE_DIR$NO_COLOR
+  * Configuration file at:$GREEN $RALLY_CONFIGURATION_DIR$NO_COLOR
+  * Samples at:$GREEN $SAMPLESDIR$NO_COLOR
 
 __EOF__
-    setup_rally_configuration "$SOURCEDIR"
 else
     setup_rally_configuration "$SOURCEDIR"
 
+    if ! [ $DEVELOPMENT_MODE ]
+    then
+        SAMPLESDIR=/usr/share/rally/samples
+        mkdir -p $SAMPLESDIR
+        cp -r $SOURCEDIR/samples/* $SAMPLESDIR/
+        if [ "$BASEDIR" != "$SOURCEDIR" ]
+        then
+            rm -rf $SOURCEDIR
+            echo "Source directory is removed."
+        else
+            echo "Unabled to remove source directory, because this script was started from it."
+
+        fi
+    else
+        SAMPLESDIR=$SOURCEDIR/samples
+    fi
+    ln -s /usr/local/etc/bash_completion.d/rally.bash_completion /etc/bash_completion.d/ 2> /dev/null || true
+    if [ -f "${DBFILE}" ]; then
+        chmod go+w "$DBFILE"
+    fi
+
     cat <<__EOF__
-==============================
+$GREEN==============================
 Installation of Rally is done!
 ==============================
-
+$NO_COLOR
 Rally is now installed in your system. Information about your Rally
 installation:
 
-  * Method: system
-  * Database at: $RALLY_DATABASE_DIR
-  * Configuration file at: $RALLY_CONFIGURATION_DIR
-
+  * Method:$GREEN system$NO_COLOR
+  * Database at:$GREEN $RALLY_DATABASE_DIR$NO_COLOR
+  * Configuration file at:$GREEN $RALLY_CONFIGURATION_DIR$NO_COLOR
+  * Samples at:$GREEN $SAMPLESDIR$NO_COLOR
 __EOF__
 fi
