@@ -14,13 +14,13 @@
 #    under the License.
 
 import abc
+import heapq
 import math
 
 import six
 
 from rally.common.i18n import _
 from rally import exceptions
-from rally.task.processing import utils
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -31,10 +31,6 @@ class StreamingAlgorithm(object):
     def add(self, value):
         """Process a single value from the input stream."""
 
-    @abc.abstractmethod
-    def merge(self, other):
-        """Merge results processed by another instance."""
-
     @abc.abstractmethod
     def result(self):
         """Return the result based on the values processed so far."""
@@ -57,10 +53,6 @@ class MeanComputation(StreamingAlgorithm):
         self.count += 1
         self.total += value
 
-    def merge(self, other):
-        self.count += other.count
-        self.total += other.total
-
     def result(self):
         if self.count == 0:
             message = _("Unable to calculate the mean: "
@@ -89,23 +81,6 @@ class StdDevComputation(StreamingAlgorithm):
         self.mean = self.mean_computation.result()
         self.dev_sum = self.dev_sum + (value - mean_prev) * (value - self.mean)
 
-    def merge(self, other):
-        dev_sum1 = self.dev_sum
-        count1 = self.count
-        mean1 = self.mean
-
-        dev_sum2 = other.dev_sum
-        count2 = other.count
-        mean2 = other.mean
-
-        self.mean_computation.merge(other.mean_computation)
-        self.mean = self.mean_computation.result()
-        self.count += other.count
-
-        self.dev_sum = (dev_sum1 + count1 * mean1 ** 2 +
-                        dev_sum2 + count2 * mean2 ** 2 -
-                        self.count * self.mean ** 2)
-
     def result(self):
         if self.count < 2:
             message = _("Unable to calculate the standard deviation: "
@@ -126,14 +101,9 @@ class MinComputation(StreamingAlgorithm):
         if self._value is None or value < self._value:
             self._value = value
 
-    def merge(self, other):
-        if other._value is not None:
-            self.add(other._value)
-
     def result(self):
         if self._value is None:
-            raise exceptions.RallyException(
-                _("No values have been processed"))
+            raise ValueError("No values have been processed")
         return self._value
 
 
@@ -149,46 +119,75 @@ class MaxComputation(StreamingAlgorithm):
         if self._value is None or value > self._value:
             self._value = value
 
-    def merge(self, other):
-        if other._value is not None:
-            self.add(other._value)
-
     def result(self):
         if self._value is None:
-            raise exceptions.RallyException(
-                _("No values have been processed"))
+            raise ValueError("No values have been processed")
         return self._value
 
 
 class PercentileComputation(StreamingAlgorithm):
     """Compute percentile value from a stream of numbers."""
 
-    def __init__(self, percent, length):
+    def __init__(self, percent):
         """Init streaming computation.
 
-        :param percent: numeric percent (from 0.00..1 to 0.999..)
-        :param length: count of the measurements
+        :param percent: numeric percent (from 0.1 to 99.9)
         """
-        if not 0 < percent < 1:
+        if not 0 < percent < 100:
             raise ValueError("Unexpected percent: %s" % percent)
         self._percent = percent
-
-        self._graph_zipper = utils.GraphZipper(length, 10000)
+        self._count = 0
+        self._left = []
+        self._right = []
+        self._current_percentile = None
 
     def add(self, value):
-        self._graph_zipper.add_point(value)
+        value = self._cast_to_float(value)
 
-    def merge(self, other):
-        # TODO(ikhudoshyn): Implement me
-        raise NotImplementedError()
+        if self._current_percentile and value > self._current_percentile:
+            heapq.heappush(self._right, value)
+        else:
+            heapq.heappush(self._left, -value)
+
+        self._count += 1
+        expected_left = int(self._percent * (self._count + 1) / 100)
+
+        if len(self._left) > expected_left:
+            heapq.heappush(self._right, -heapq.heappop(self._left))
+        elif len(self._left) < expected_left:
+            heapq.heappush(self._left, -heapq.heappop(self._right))
+
+        left = -self._left[0] if len(self._left) else 0
+        right = self._right[0] if len(self._right) else 0
+
+        self._current_percentile = left + (right - left) / 2.
 
     def result(self):
-        results = list(
-            map(lambda x: x[1], self._graph_zipper.get_zipped_graph()))
-        if not results:
-            raise exceptions.RallyException(
-                _("No values have been processed"))
-        return utils.percentile(results, self._percent)
+        if self._current_percentile is None:
+            raise ValueError("No values have been processed")
+        return self._current_percentile
+
+
+class ProgressComputation(StreamingAlgorithm):
+    """Compute progress in percent."""
+
+    def __init__(self, base_count):
+        """Init streaming computation.
+
+        :param base_count: int number for end progress (100% reached)
+        """
+        self._base_count = int(base_count) or 1
+        self._count = 0
+
+    def add(self, *args):
+        if self._count >= self._base_count:
+            raise RuntimeError(
+                "100%% progress is already reached (count of %d)"
+                % self._base_count)
+        self._count += 1
+
+    def result(self):
+        return self._count / float(self._base_count) * 100
 
 
 class IncrementComputation(StreamingAlgorithm):
@@ -200,8 +199,5 @@ class IncrementComputation(StreamingAlgorithm):
     def add(self, *args):
         self._count += 1
 
-    def merge(self, other):
-        self._count += other._count
-
     def result(self):
         return self._count
