@@ -24,7 +24,7 @@ mkdir -p ${RESULTS_DIR}/extra
 
 
 # Check deployment
-rally use deployment --deployment devstack
+rally deployment use --deployment devstack
 rally deployment check
 
 function do_status {
@@ -38,17 +38,18 @@ function do_status {
 
 declare -a RESULTS
 
-rally-manage --rally-debug tempest install > ${RESULTS_DIR}/tempest_installation.txt 2>&1
+rally --rally-debug verify install > ${RESULTS_DIR}/tempest_installation.txt 2>&1
 RESULTS+="install=$(do_status $?) "
 
-gzip -9 ${RESULTS_DIR}/tempest_installation.txt
+rally --rally-debug verify genconfig --tempest-config ${RESULTS_DIR}/tempest.conf > ${RESULTS_DIR}/tempest_config_generation.txt 2>&1
+RESULTS+="genconfig=$(do_status $?) "
 
-# Run to verification for one SET_NAME and then compare them.
-SET_NAME="compute"
+gzip -9 ${RESULTS_DIR}/tempest_installation.txt
+gzip -9 ${RESULTS_DIR}/tempest_config_generation.txt
 
 function do_verification {
     OUTPUT_FILE=${RESULTS_DIR}/${1}_verification_${SET_NAME}_set.txt
-    rally --rally-debug verify start --set ${SET_NAME} > ${OUTPUT_FILE} 2>&1
+    rally --rally-debug verify start --regex tempest.api.compute.servers.test_servers > ${OUTPUT_FILE} 2>&1
     RESULTS+="v${1}=$(do_status $?) "
     gzip -9 ${OUTPUT_FILE}
     source ~/.rally/globals && VERIFICATIONS[${1}]=${RALLY_VERIFICATION}
