@@ -13,10 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import math
-
 import ddt
-import six
+
+import math
 
 from rally.common import streaming_algorithms as algo
 from rally import exceptions
@@ -42,27 +41,6 @@ class MeanComputationTestCase(test.TestCase):
         excepted_mean = float(sum(stream)) / len(stream)
         self.assertEqual(excepted_mean, mean_computation.result())
 
-    def test_merge(self):
-        single_mean = algo.MeanComputation()
-
-        for val in six.moves.range(100):
-            single_mean.add(val)
-
-        means = [algo.MeanComputation()
-                 for _ in six.moves.range(10)]
-
-        for idx, mean in enumerate(means):
-            for val in six.moves.range(idx * 10, (idx + 1) * 10):
-                mean.add(val)
-
-        merged_mean = means[0]
-        for mean in means[1:]:
-            merged_mean.merge(mean)
-
-        self.assertEqual(single_mean.count, merged_mean.count)
-        self.assertEqual(single_mean.total, merged_mean.total)
-        self.assertEqual(single_mean.result(), merged_mean.result())
-
 
 class StdDevComputationTestCase(test.TestCase):
 
@@ -91,28 +69,6 @@ class StdDevComputationTestCase(test.TestCase):
                                  (len(stream) - 1))
         self.assertEqual(excepted_std, std_computation.result())
 
-    def test_merge(self):
-        single_std = algo.StdDevComputation()
-
-        for val in six.moves.range(100):
-            single_std.add(val)
-
-        stds = [algo.StdDevComputation()
-                for _ in six.moves.range(10)]
-
-        for idx, std in enumerate(stds):
-            for val in six.moves.range(idx * 10, (idx + 1) * 10):
-                std.add(val)
-
-        merged_std = stds[0]
-        for std in stds[1:]:
-            merged_std.merge(std)
-
-        self.assertEqual(single_std.count, merged_std.count)
-        self.assertEqual(single_std.mean, merged_std.mean)
-        self.assertEqual(single_std.dev_sum, merged_std.dev_sum)
-        self.assertEqual(single_std.result(), merged_std.result())
-
 
 class MinComputationTestCase(test.TestCase):
 
@@ -130,27 +86,7 @@ class MinComputationTestCase(test.TestCase):
     def test_result_raises(self):
         comp = algo.MinComputation()
         self.assertRaises(TypeError, comp.result, 1)
-        self.assertRaises(exceptions.RallyException, comp.result)
-
-    def test_merge(self):
-        single_min_algo = algo.MinComputation()
-
-        for val in six.moves.range(100):
-            single_min_algo.add(val)
-
-        algos = [algo.MinComputation()
-                 for _ in six.moves.range(10)]
-
-        for idx, min_algo in enumerate(algos):
-            for val in six.moves.range(idx * 10, (idx + 1) * 10):
-                min_algo.add(val)
-
-        merged_min_algo = algos[0]
-        for min_algo in algos[1:]:
-            merged_min_algo.merge(min_algo)
-
-        self.assertEqual(single_min_algo._value, merged_min_algo._value)
-        self.assertEqual(single_min_algo.result(), merged_min_algo.result())
+        self.assertRaises(ValueError, comp.result)
 
 
 class MaxComputationTestCase(test.TestCase):
@@ -169,35 +105,12 @@ class MaxComputationTestCase(test.TestCase):
     def test_result_raises(self):
         comp = algo.MaxComputation()
         self.assertRaises(TypeError, comp.result, 1)
-        self.assertRaises(exceptions.RallyException, comp.result)
-
-    def test_merge(self):
-        single_max_algo = algo.MaxComputation()
-
-        for val in six.moves.range(100):
-            single_max_algo.add(val)
-
-        algos = [algo.MaxComputation()
-                 for _ in six.moves.range(10)]
-
-        for idx, max_algo in enumerate(algos):
-            for val in six.moves.range(idx * 10, (idx + 1) * 10):
-                max_algo.add(val)
-
-        merged_max_algo = algos[0]
-        for max_algo in algos[1:]:
-            merged_max_algo.merge(max_algo)
-
-        self.assertEqual(single_max_algo._value, merged_max_algo._value)
-        self.assertEqual(single_max_algo.result(), merged_max_algo.result())
+        self.assertRaises(ValueError, comp.result)
 
 
 @ddt.ddt
 class PercentileComputationTestCase(test.TestCase):
 
-    mixed1 = [0]
-    mixed6 = [100, 100, 0, 100, 100, 100]
-    mixed5 = [0, 0, 100, 0, 0]
     mixed16 = [55.71, 83.05, 24.12, 27, 48.36, 16.36, 96.23, 6, 16.0, 88.11,
                29.52, 99.2, 79.96, 77.84, 85.45, 85.32, 7, 17.1, 3.02, 15.23]
     mixed50 = [51.63, 82.2, 52.52, .05, 66, 94.03, 78.6, 80.9, 51.89, 79, 1.4,
@@ -209,42 +122,56 @@ class PercentileComputationTestCase(test.TestCase):
     range5000 = range(5000)
 
     @ddt.data(
-        {"stream": "mixed1", "percent": 0.95, "expected": 0},
-        {"stream": "mixed6", "percent": 0.5, "expected": 100},
-        {"stream": "mixed5", "percent": 0.5, "expected": 0},
-        {"stream": "mixed5", "percent": 0.999, "expected": 99.6},
-        {"stream": "mixed5", "percent": 0.001, "expected": 0},
-        {"stream": "mixed16", "percent": 0.25, "expected": 16.27},
-        {"stream": "mixed16", "percent": 0.50, "expected": 38.94},
-        {"stream": "mixed16", "percent": 0.90, "expected":
-            88.92200000000001},
-        {"stream": "mixed50", "percent": 0.25, "expected": 25.105},
-        {"stream": "mixed50", "percent": 0.50, "expected": 51.89},
-        {"stream": "mixed50", "percent": 0.90, "expected":
-            82.81300000000002},
-        {"stream": "mixed5000", "percent": 0.25, "expected":
-            35.54600000000001},
-        {"stream": "mixed5000", "percent": 0.50, "expected": 48.351},
-        {"stream": "mixed5000", "percent": 0.90, "expected":
-            66.05880000000437},
-        {"stream": "range5000", "percent": 0.25, "expected": 1249.75},
-        {"stream": "range5000", "percent": 0.50, "expected": 2499.5},
-        {"stream": "range5000", "percent": 0.90, "expected": 4499.1})
+        {"stream": "mixed16", "percent": 25, "expected": 16.18},
+        {"stream": "mixed16", "percent": 50, "expected": 38.94},
+        {"stream": "mixed16", "percent": 90, "expected": 92.17},
+        {"stream": "mixed50", "percent": 25, "expected": 23.1},
+        {"stream": "mixed50", "percent": 50, "expected": 51.89},
+        {"stream": "mixed50", "percent": 90, "expected": 85.265},
+        {"stream": "mixed5000", "percent": 25, "expected": 25.03},
+        {"stream": "mixed5000", "percent": 50, "expected": 51.89},
+        {"stream": "mixed5000", "percent": 90, "expected": 85.265},
+        {"stream": "range5000", "percent": 25, "expected": 1249.5},
+        {"stream": "range5000", "percent": 50, "expected": 2499.5},
+        {"stream": "range5000", "percent": 90, "expected": 4499.5})
     @ddt.unpack
     def test_add_and_result(self, percent, stream, expected):
-        comp = algo.PercentileComputation(percent=percent, length=len(
-            getattr(self, stream)))
+        comp = algo.PercentileComputation(percent=percent)
         [comp.add(i) for i in getattr(self, stream)]
         self.assertEqual(expected, comp.result())
 
     def test_add_raises(self):
-        comp = algo.PercentileComputation(0.50, 100)
+        comp = algo.PercentileComputation(50)
         self.assertRaises(TypeError, comp.add)
+        self.assertRaises(TypeError, comp.add, None)
+        self.assertRaises(TypeError, comp.add, "str")
 
     def test_result_raises(self):
         self.assertRaises(TypeError, algo.PercentileComputation)
-        comp = algo.PercentileComputation(0.50, 100)
-        self.assertRaises(exceptions.RallyException, comp.result)
+        comp = algo.PercentileComputation(50)
+        self.assertRaises(ValueError, comp.result)
+
+
+class ProgressComputationTestCase(test.TestCase):
+
+    def test___init__raises(self):
+        self.assertRaises(TypeError, algo.ProgressComputation)
+        self.assertRaises(TypeError, algo.ProgressComputation, None)
+        self.assertRaises(ValueError, algo.ProgressComputation, "str")
+
+    def test_add_and_result(self):
+        comp = algo.ProgressComputation(42)
+        self.assertEqual(0, comp.result())
+        for expected_progress in (2.38, 4.76, 7.14, 9.52, 11.9, 14.29,
+                                  16.67, 19.05, 21.43):
+            comp.add(42)
+            self.assertEqual(expected_progress, round(comp.result(), 2))
+
+    def test_add_raises(self):
+        comp = algo.ProgressComputation(42)
+        [comp.add(123) for i in range(42)]
+        self.assertRaises(RuntimeError, comp.add, None)
+        self.assertRaises(RuntimeError, comp.add, 123)
 
 
 class IncrementComputationTestCase(test.TestCase):
@@ -255,23 +182,3 @@ class IncrementComputationTestCase(test.TestCase):
             self.assertEqual(i - 1, comp.result())
             comp.add(42)
             self.assertEqual(i, comp.result())
-
-    def test_merge(self):
-        single_inc = algo.IncrementComputation()
-
-        for val in six.moves.range(100):
-            single_inc.add(val)
-
-        incs = [algo.IncrementComputation()
-                for _ in six.moves.range(10)]
-
-        for idx, inc in enumerate(incs):
-            for val in six.moves.range(idx * 10, (idx + 1) * 10):
-                inc.add(val)
-
-        merged_inc = incs[0]
-        for inc in incs[1:]:
-            merged_inc.merge(inc)
-
-        self.assertEqual(single_inc._count, merged_inc._count)
-        self.assertEqual(single_inc.result(), merged_inc.result())
