@@ -281,13 +281,13 @@ class VMScenarioTestCase(test.ScenarioTestCase):
         scenario._attach_floating_ip(
             server, floating_network="bar_network")
 
-        mock_wrap.assert_called_once_with(scenario.clients, scenario)
+        mock_wrap.assert_called_once_with(scenario.clients)
         netwrap.create_floating_ip.assert_called_once_with(
             ext_network="bar_network",
             tenant_id="foo_tenant", fixed_ip="foo_ip")
 
         scenario._associate_floating_ip.assert_called_once_with(
-            server, "foo_ip", fixed_address="foo_ip", atomic_action=False)
+            server, "foo_ip", fixed_address="foo_ip")
 
     @mock.patch(VMTASKS_UTILS + ".network_wrapper.wrap")
     def test__delete_floating_ip(self, mock_wrap):
@@ -304,7 +304,7 @@ class VMScenarioTestCase(test.ScenarioTestCase):
             "foo_ip")
         _check_addr.assert_called_once_with(server)
         scenario._dissociate_floating_ip.assert_called_once_with(
-            server, "foo_ip", atomic_action=False)
-        mock_wrap.assert_called_once_with(scenario.clients, scenario)
+            server, "foo_ip")
+        mock_wrap.assert_called_once_with(scenario.clients)
         mock_wrap.return_value.delete_floating_ip.assert_called_once_with(
             "foo_id", wait=True)
